"""


Mesh Select Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:VERT:            
  Vertex.

  Vertex selection mode.

:EDGE:            
  Edge.

  Edge selection mode.

:FACE:            
  Face.

  Face selection mode.

.. _rna-enum-mesh-select-mode-items:

"""

import typing
