"""


Volume Grid Data Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BOOLEAN:         
  Boolean.

  Boolean.

:FLOAT:           
  Float.

  Single precision float.

:DOUBLE:          
  Double.

  Double precision.

:INT:             
  Integer.

  32-bit integer.

:INT64:           
  Integer 64-bit.

  64-bit integer.

:MASK:            
  Mask.

  No data, boolean mask of active voxels.

:VECTOR_FLOAT:    
  Float Vector.

  3D float vector.

:VECTOR_DOUBLE:   
  Double Vector.

  3D double vector.

:VECTOR_INT:      
  Integer Vector.

  3D integer vector.

:POINTS:          
  Points (Unsupported).

  Points grid, currently unsupported by volume objects.

:UNKNOWN:         
  Unknown.

  Unsupported data type.

.. _rna-enum-volume-grid-data-type-items:

"""

import typing
