"""


Boidrule Type Items
^^^^^^^^^^^^^^^^^^^

:GOAL:            
  Goal.

  Go to assigned object or loudest assigned signal source.

:AVOID:           
  Avoid.

  Get away from assigned object or loudest assigned signal source.

:AVOID_COLLISION: 
  Avoid Collision.

  Maneuver to avoid collisions with other boids and deflector objects in near future.

:SEPARATE:        
  Separate.

  Keep from going through other boids.

:FLOCK:           
  Flock.

  Move to center of neighbors and match their velocity.

:FOLLOW_LEADER:   
  Follow Leader.

  Follow a boid or assigned object.

:AVERAGE_SPEED:   
  Average Speed.

  Maintain speed, flight level or wander.

:FIGHT:           
  Fight.

  Go to closest enemy and attack when in range.

.. _rna-enum-boidrule-type-items:

"""

import typing
