"""


Views Format Multiview Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:INDIVIDUAL:      
  Individual.

  Individual files for each view with the prefix as defined by the scene views.

:STEREO_3D:       
  Stereo 3D.

  Single file with an encoded stereo pair.

:MULTIVIEW:       
  Multi-View.

  Single file with all the views.

.. _rna-enum-views-format-multiview-items:

"""

import typing
