"""


Icon Items
^^^^^^^^^^

:NONE:            
  NONE.

:QUESTION:        
  QUESTION.

:ERROR:           
  ERROR.

:CANCEL:          
  CANCEL.

:TRIA_RIGHT:      
  TRIA_RIGHT.

:TRIA_DOWN:       
  TRIA_DOWN.

:TRIA_LEFT:       
  TRIA_LEFT.

:TRIA_UP:         
  TRIA_UP.

:ARROW_LEFTRIGHT: 
  ARROW_LEFTRIGHT.

:PLUS:            
  PLUS.

:DISCLOSURE_TRI_RIGHT:
  DISCLOSURE_TRI_RIGHT.

:DISCLOSURE_TRI_DOWN:
  DISCLOSURE_TRI_DOWN.

:RADIOBUT_OFF:    
  RADIOBUT_OFF.

:RADIOBUT_ON:     
  RADIOBUT_ON.

:MENU_PANEL:      
  MENU_PANEL.

:BLENDER:         
  BLENDER.

:GRIP:            
  GRIP.

:DOT:             
  DOT.

:COLLAPSEMENU:    
  COLLAPSEMENU.

:X:               
:DUPLICATE:       
  DUPLICATE.

:TRASH:           
  TRASH.

:COLLECTION_NEW:  
  COLLECTION_NEW.

:OPTIONS:         
  OPTIONS.

:NODE:            
  NODE.

:NODE_SEL:        
  NODE_SEL.

:WINDOW:          
  WINDOW.

:WORKSPACE:       
  WORKSPACE.

:RIGHTARROW_THIN: 
  RIGHTARROW_THIN.

:BORDERMOVE:      
  BORDERMOVE.

:VIEWZOOM:        
  VIEWZOOM.

:ADD:             
  ADD.

:REMOVE:          
  REMOVE.

:PANEL_CLOSE:     
  PANEL_CLOSE.

:COPY_ID:         
  COPY_ID.

:EYEDROPPER:      
  EYEDROPPER.

:CHECKMARK:       
  CHECKMARK.

:AUTO:            
  AUTO.

:CHECKBOX_DEHLT:  
  CHECKBOX_DEHLT.

:CHECKBOX_HLT:    
  CHECKBOX_HLT.

:UNLOCKED:        
  UNLOCKED.

:LOCKED:          
  LOCKED.

:UNPINNED:        
  UNPINNED.

:PINNED:          
  PINNED.

:SCREEN_BACK:     
  SCREEN_BACK.

:RIGHTARROW:      
  RIGHTARROW.

:DOWNARROW_HLT:   
  DOWNARROW_HLT.

:FCURVE_SNAPSHOT: 
  FCURVE_SNAPSHOT.

:OBJECT_HIDDEN:   
  OBJECT_HIDDEN.

:TOPBAR:          
  TOPBAR.

:STATUSBAR:       
  STATUSBAR.

:PLUGIN:          
  PLUGIN.

:HELP:            
  HELP.

:GHOST_ENABLED:   
  GHOST_ENABLED.

:COLOR:           
  COLOR.

:UNLINKED:        
  UNLINKED.

:LINKED:          
  LINKED.

:HAND:            
  HAND.

:ZOOM_ALL:        
  ZOOM_ALL.

:ZOOM_SELECTED:   
  ZOOM_SELECTED.

:ZOOM_PREVIOUS:   
  ZOOM_PREVIOUS.

:ZOOM_IN:         
  ZOOM_IN.

:ZOOM_OUT:        
  ZOOM_OUT.

:DRIVER_DISTANCE: 
  DRIVER_DISTANCE.

:DRIVER_ROTATIONAL_DIFFERENCE:
  DRIVER_ROTATIONAL_DIFFERENCE.

:DRIVER_TRANSFORM:
  DRIVER_TRANSFORM.

:FREEZE:          
  FREEZE.

:STYLUS_PRESSURE: 
  STYLUS_PRESSURE.

:GHOST_DISABLED:  
  GHOST_DISABLED.

:FILE_NEW:        
  FILE_NEW.

:FILE_TICK:       
  FILE_TICK.

:QUIT:            
  QUIT.

:URL:             
  URL.

:RECOVER_LAST:    
  RECOVER_LAST.

:THREE_DOTS:      
  THREE_DOTS.

:FULLSCREEN_ENTER:
  FULLSCREEN_ENTER.

:FULLSCREEN_EXIT: 
  FULLSCREEN_EXIT.

:BRUSHES_ALL:     
  BRUSHES_ALL.

:LIGHT:           
  LIGHT.

:MATERIAL:        
  MATERIAL.

:TEXTURE:         
  TEXTURE.

:ANIM:            
  ANIM.

:WORLD:           
  WORLD.

:SCENE:           
  SCENE.

:OUTPUT:          
  OUTPUT.

:SCRIPT:          
  SCRIPT.

:PARTICLES:       
  PARTICLES.

:PHYSICS:         
  PHYSICS.

:SPEAKER:         
  SPEAKER.

:TOOL_SETTINGS:   
  TOOL_SETTINGS.

:SHADERFX:        
  SHADERFX.

:MODIFIER:        
  MODIFIER.

:BLANK1:          
  BLANK1.

:FAKE_USER_OFF:   
  FAKE_USER_OFF.

:FAKE_USER_ON:    
  FAKE_USER_ON.

:VIEW3D:          
  VIEW3D.

:GRAPH:           
  GRAPH.

:OUTLINER:        
  OUTLINER.

:PROPERTIES:      
  PROPERTIES.

:FILEBROWSER:     
  FILEBROWSER.

:IMAGE:           
  IMAGE.

:INFO:            
  INFO.

:SEQUENCE:        
  SEQUENCE.

:TEXT:            
  TEXT.

:SPREADSHEET:     
  SPREADSHEET.

:SOUND:           
  SOUND.

:ACTION:          
  ACTION.

:NLA:             
  NLA.

:PREFERENCES:     
  PREFERENCES.

:TIME:            
  TIME.

:NODETREE:        
  NODETREE.

:GEOMETRY_NODES:  
  GEOMETRY_NODES.

:CONSOLE:         
  CONSOLE.

:TRACKER:         
  TRACKER.

:ASSET_MANAGER:   
  ASSET_MANAGER.

:NODE_COMPOSITING:
  NODE_COMPOSITING.

:NODE_TEXTURE:    
  NODE_TEXTURE.

:NODE_MATERIAL:   
  NODE_MATERIAL.

:UV:              
  UV.

:OBJECT_DATAMODE: 
  OBJECT_DATAMODE.

:EDITMODE_HLT:    
  EDITMODE_HLT.

:UV_DATA:         
  UV_DATA.

:VPAINT_HLT:      
  VPAINT_HLT.

:TPAINT_HLT:      
  TPAINT_HLT.

:WPAINT_HLT:      
  WPAINT_HLT.

:SCULPTMODE_HLT:  
  SCULPTMODE_HLT.

:POSE_HLT:        
  POSE_HLT.

:PARTICLEMODE:    
  PARTICLEMODE.

:TRACKING:        
  TRACKING.

:TRACKING_BACKWARDS:
  TRACKING_BACKWARDS.

:TRACKING_FORWARDS:
  TRACKING_FORWARDS.

:TRACKING_BACKWARDS_SINGLE:
  TRACKING_BACKWARDS_SINGLE.

:TRACKING_FORWARDS_SINGLE:
  TRACKING_FORWARDS_SINGLE.

:TRACKING_CLEAR_BACKWARDS:
  TRACKING_CLEAR_BACKWARDS.

:TRACKING_CLEAR_FORWARDS:
  TRACKING_CLEAR_FORWARDS.

:TRACKING_REFINE_BACKWARDS:
  TRACKING_REFINE_BACKWARDS.

:TRACKING_REFINE_FORWARDS:
  TRACKING_REFINE_FORWARDS.

:SCENE_DATA:      
  SCENE_DATA.

:RENDERLAYERS:    
  RENDERLAYERS.

:WORLD_DATA:      
  WORLD_DATA.

:OBJECT_DATA:     
  OBJECT_DATA.

:MESH_DATA:       
  MESH_DATA.

:CURVE_DATA:      
  CURVE_DATA.

:META_DATA:       
  META_DATA.

:LATTICE_DATA:    
  LATTICE_DATA.

:LIGHT_DATA:      
  LIGHT_DATA.

:MATERIAL_DATA:   
  MATERIAL_DATA.

:TEXTURE_DATA:    
  TEXTURE_DATA.

:ANIM_DATA:       
  ANIM_DATA.

:CAMERA_DATA:     
  CAMERA_DATA.

:PARTICLE_DATA:   
  PARTICLE_DATA.

:LIBRARY_DATA_DIRECT:
  LIBRARY_DATA_DIRECT.

:GROUP:           
  GROUP.

:ARMATURE_DATA:   
  ARMATURE_DATA.

:COMMUNITY:       
  COMMUNITY.

:BONE_DATA:       
  BONE_DATA.

:CONSTRAINT:      
  CONSTRAINT.

:SHAPEKEY_DATA:   
  SHAPEKEY_DATA.

:CONSTRAINT_BONE: 
  CONSTRAINT_BONE.

:CAMERA_STEREO:   
  CAMERA_STEREO.

:PACKAGE:         
  PACKAGE.

:UGLYPACKAGE:     
  UGLYPACKAGE.

:EXPERIMENTAL:    
  EXPERIMENTAL.

:BRUSH_DATA:      
  BRUSH_DATA.

:IMAGE_DATA:      
  IMAGE_DATA.

:FILE:            
  FILE.

:FCURVE:          
  FCURVE.

:FONT_DATA:       
  FONT_DATA.

:RENDER_RESULT:   
  RENDER_RESULT.

:SURFACE_DATA:    
  SURFACE_DATA.

:EMPTY_DATA:      
  EMPTY_DATA.

:PRESET:          
  PRESET.

:RENDER_ANIMATION:
  RENDER_ANIMATION.

:RENDER_STILL:    
  RENDER_STILL.

:LIBRARY_DATA_BROKEN:
  LIBRARY_DATA_BROKEN.

:BOIDS:           
  BOIDS.

:STRANDS:         
  STRANDS.

:GREASEPENCIL:    
  GREASEPENCIL.

:LINE_DATA:       
  LINE_DATA.

:LIBRARY_DATA_OVERRIDE:
  LIBRARY_DATA_OVERRIDE.

:GROUP_BONE:      
  GROUP_BONE.

:GROUP_VERTEX:    
  GROUP_VERTEX.

:GROUP_VCOL:      
  GROUP_VCOL.

:GROUP_UVS:       
  GROUP_UVS.

:FACE_MAPS:       
  FACE_MAPS.

:RNA:             
  RNA.

:RNA_ADD:         
  RNA_ADD.

:MOUSE_LMB:       
  MOUSE_LMB.

:MOUSE_MMB:       
  MOUSE_MMB.

:MOUSE_RMB:       
  MOUSE_RMB.

:MOUSE_MOVE:      
  MOUSE_MOVE.

:MOUSE_LMB_DRAG:  
  MOUSE_LMB_DRAG.

:MOUSE_MMB_DRAG:  
  MOUSE_MMB_DRAG.

:MOUSE_RMB_DRAG:  
  MOUSE_RMB_DRAG.

:MEMORY:          
  MEMORY.

:PRESET_NEW:      
  PRESET_NEW.

:DECORATE:        
  DECORATE.

:DECORATE_KEYFRAME:
  DECORATE_KEYFRAME.

:DECORATE_ANIMATE:
  DECORATE_ANIMATE.

:DECORATE_DRIVER: 
  DECORATE_DRIVER.

:DECORATE_LINKED: 
  DECORATE_LINKED.

:DECORATE_LIBRARY_OVERRIDE:
  DECORATE_LIBRARY_OVERRIDE.

:DECORATE_UNLOCKED:
  DECORATE_UNLOCKED.

:DECORATE_LOCKED: 
  DECORATE_LOCKED.

:DECORATE_OVERRIDE:
  DECORATE_OVERRIDE.

:FUND:            
  FUND.

:TRACKER_DATA:    
  TRACKER_DATA.

:HEART:           
  HEART.

:ORPHAN_DATA:     
  ORPHAN_DATA.

:USER:            
  USER.

:SYSTEM:          
  SYSTEM.

:SETTINGS:        
  SETTINGS.

:OUTLINER_OB_EMPTY:
  OUTLINER_OB_EMPTY.

:OUTLINER_OB_MESH:
  OUTLINER_OB_MESH.

:OUTLINER_OB_CURVE:
  OUTLINER_OB_CURVE.

:OUTLINER_OB_LATTICE:
  OUTLINER_OB_LATTICE.

:OUTLINER_OB_META:
  OUTLINER_OB_META.

:OUTLINER_OB_LIGHT:
  OUTLINER_OB_LIGHT.

:OUTLINER_OB_CAMERA:
  OUTLINER_OB_CAMERA.

:OUTLINER_OB_ARMATURE:
  OUTLINER_OB_ARMATURE.

:OUTLINER_OB_FONT:
  OUTLINER_OB_FONT.

:OUTLINER_OB_SURFACE:
  OUTLINER_OB_SURFACE.

:OUTLINER_OB_SPEAKER:
  OUTLINER_OB_SPEAKER.

:OUTLINER_OB_FORCE_FIELD:
  OUTLINER_OB_FORCE_FIELD.

:OUTLINER_OB_GROUP_INSTANCE:
  OUTLINER_OB_GROUP_INSTANCE.

:OUTLINER_OB_GREASEPENCIL:
  OUTLINER_OB_GREASEPENCIL.

:OUTLINER_OB_LIGHTPROBE:
  OUTLINER_OB_LIGHTPROBE.

:OUTLINER_OB_IMAGE:
  OUTLINER_OB_IMAGE.

:OUTLINER_COLLECTION:
  OUTLINER_COLLECTION.

:RESTRICT_COLOR_OFF:
  RESTRICT_COLOR_OFF.

:RESTRICT_COLOR_ON:
  RESTRICT_COLOR_ON.

:HIDE_ON:         
  HIDE_ON.

:HIDE_OFF:        
  HIDE_OFF.

:RESTRICT_SELECT_ON:
  RESTRICT_SELECT_ON.

:RESTRICT_SELECT_OFF:
  RESTRICT_SELECT_OFF.

:RESTRICT_RENDER_ON:
  RESTRICT_RENDER_ON.

:RESTRICT_RENDER_OFF:
  RESTRICT_RENDER_OFF.

:RESTRICT_INSTANCED_OFF:
  RESTRICT_INSTANCED_OFF.

:OUTLINER_DATA_EMPTY:
  OUTLINER_DATA_EMPTY.

:OUTLINER_DATA_MESH:
  OUTLINER_DATA_MESH.

:OUTLINER_DATA_CURVE:
  OUTLINER_DATA_CURVE.

:OUTLINER_DATA_LATTICE:
  OUTLINER_DATA_LATTICE.

:OUTLINER_DATA_META:
  OUTLINER_DATA_META.

:OUTLINER_DATA_LIGHT:
  OUTLINER_DATA_LIGHT.

:OUTLINER_DATA_CAMERA:
  OUTLINER_DATA_CAMERA.

:OUTLINER_DATA_ARMATURE:
  OUTLINER_DATA_ARMATURE.

:OUTLINER_DATA_FONT:
  OUTLINER_DATA_FONT.

:OUTLINER_DATA_SURFACE:
  OUTLINER_DATA_SURFACE.

:OUTLINER_DATA_SPEAKER:
  OUTLINER_DATA_SPEAKER.

:OUTLINER_DATA_LIGHTPROBE:
  OUTLINER_DATA_LIGHTPROBE.

:OUTLINER_DATA_GP_LAYER:
  OUTLINER_DATA_GP_LAYER.

:OUTLINER_DATA_GREASEPENCIL:
  OUTLINER_DATA_GREASEPENCIL.

:GP_SELECT_POINTS:
  GP_SELECT_POINTS.

:GP_SELECT_STROKES:
  GP_SELECT_STROKES.

:GP_MULTIFRAME_EDITING:
  GP_MULTIFRAME_EDITING.

:GP_ONLY_SELECTED:
  GP_ONLY_SELECTED.

:GP_SELECT_BETWEEN_STROKES:
  GP_SELECT_BETWEEN_STROKES.

:MODIFIER_OFF:    
  MODIFIER_OFF.

:MODIFIER_ON:     
  MODIFIER_ON.

:ONIONSKIN_OFF:   
  ONIONSKIN_OFF.

:ONIONSKIN_ON:    
  ONIONSKIN_ON.

:RESTRICT_VIEW_ON:
  RESTRICT_VIEW_ON.

:RESTRICT_VIEW_OFF:
  RESTRICT_VIEW_OFF.

:RESTRICT_INSTANCED_ON:
  RESTRICT_INSTANCED_ON.

:MESH_PLANE:      
  MESH_PLANE.

:MESH_CUBE:       
  MESH_CUBE.

:MESH_CIRCLE:     
  MESH_CIRCLE.

:MESH_UVSPHERE:   
  MESH_UVSPHERE.

:MESH_ICOSPHERE:  
  MESH_ICOSPHERE.

:MESH_GRID:       
  MESH_GRID.

:MESH_MONKEY:     
  MESH_MONKEY.

:MESH_CYLINDER:   
  MESH_CYLINDER.

:MESH_TORUS:      
  MESH_TORUS.

:MESH_CONE:       
  MESH_CONE.

:MESH_CAPSULE:    
  MESH_CAPSULE.

:EMPTY_SINGLE_ARROW:
  EMPTY_SINGLE_ARROW.

:LIGHT_POINT:     
  LIGHT_POINT.

:LIGHT_SUN:       
  LIGHT_SUN.

:LIGHT_SPOT:      
  LIGHT_SPOT.

:LIGHT_HEMI:      
  LIGHT_HEMI.

:LIGHT_AREA:      
  LIGHT_AREA.

:CUBE:            
  CUBE.

:SPHERE:          
  SPHERE.

:CONE:            
  CONE.

:META_PLANE:      
  META_PLANE.

:META_CUBE:       
  META_CUBE.

:META_BALL:       
  META_BALL.

:META_ELLIPSOID:  
  META_ELLIPSOID.

:META_CAPSULE:    
  META_CAPSULE.

:SURFACE_NCURVE:  
  SURFACE_NCURVE.

:SURFACE_NCIRCLE: 
  SURFACE_NCIRCLE.

:SURFACE_NSURFACE:
  SURFACE_NSURFACE.

:SURFACE_NCYLINDER:
  SURFACE_NCYLINDER.

:SURFACE_NSPHERE: 
  SURFACE_NSPHERE.

:SURFACE_NTORUS:  
  SURFACE_NTORUS.

:EMPTY_AXIS:      
  EMPTY_AXIS.

:STROKE:          
  STROKE.

:EMPTY_ARROWS:    
  EMPTY_ARROWS.

:CURVE_BEZCURVE:  
  CURVE_BEZCURVE.

:CURVE_BEZCIRCLE: 
  CURVE_BEZCIRCLE.

:CURVE_NCURVE:    
  CURVE_NCURVE.

:CURVE_NCIRCLE:   
  CURVE_NCIRCLE.

:CURVE_PATH:      
  CURVE_PATH.

:LIGHTPROBE_CUBEMAP:
  LIGHTPROBE_CUBEMAP.

:LIGHTPROBE_PLANAR:
  LIGHTPROBE_PLANAR.

:LIGHTPROBE_GRID: 
  LIGHTPROBE_GRID.

:COLOR_RED:       
  COLOR_RED.

:COLOR_GREEN:     
  COLOR_GREEN.

:COLOR_BLUE:      
  COLOR_BLUE.

:TRIA_RIGHT_BAR:  
  TRIA_RIGHT_BAR.

:TRIA_DOWN_BAR:   
  TRIA_DOWN_BAR.

:TRIA_LEFT_BAR:   
  TRIA_LEFT_BAR.

:TRIA_UP_BAR:     
  TRIA_UP_BAR.

:FORCE_FORCE:     
  FORCE_FORCE.

:FORCE_WIND:      
  FORCE_WIND.

:FORCE_VORTEX:    
  FORCE_VORTEX.

:FORCE_MAGNETIC:  
  FORCE_MAGNETIC.

:FORCE_HARMONIC:  
  FORCE_HARMONIC.

:FORCE_CHARGE:    
  FORCE_CHARGE.

:FORCE_LENNARDJONES:
  FORCE_LENNARDJONES.

:FORCE_TEXTURE:   
  FORCE_TEXTURE.

:FORCE_CURVE:     
  FORCE_CURVE.

:FORCE_BOID:      
  FORCE_BOID.

:FORCE_TURBULENCE:
  FORCE_TURBULENCE.

:FORCE_DRAG:      
  FORCE_DRAG.

:FORCE_FLUIDFLOW: 
  FORCE_FLUIDFLOW.

:RIGID_BODY:      
  RIGID_BODY.

:RIGID_BODY_CONSTRAINT:
  RIGID_BODY_CONSTRAINT.

:IMAGE_PLANE:     
  IMAGE_PLANE.

:IMAGE_BACKGROUND:
  IMAGE_BACKGROUND.

:IMAGE_REFERENCE: 
  IMAGE_REFERENCE.

:NODE_INSERT_ON:  
  NODE_INSERT_ON.

:NODE_INSERT_OFF: 
  NODE_INSERT_OFF.

:NODE_TOP:        
  NODE_TOP.

:NODE_SIDE:       
  NODE_SIDE.

:NODE_CORNER:     
  NODE_CORNER.

:ANCHOR_TOP:      
  ANCHOR_TOP.

:ANCHOR_BOTTOM:   
  ANCHOR_BOTTOM.

:ANCHOR_LEFT:     
  ANCHOR_LEFT.

:ANCHOR_RIGHT:    
  ANCHOR_RIGHT.

:ANCHOR_CENTER:   
  ANCHOR_CENTER.

:SELECT_SET:      
  SELECT_SET.

:SELECT_EXTEND:   
  SELECT_EXTEND.

:SELECT_SUBTRACT: 
  SELECT_SUBTRACT.

:SELECT_INTERSECT:
  SELECT_INTERSECT.

:SELECT_DIFFERENCE:
  SELECT_DIFFERENCE.

:ALIGN_LEFT:      
  ALIGN_LEFT.

:ALIGN_CENTER:    
  ALIGN_CENTER.

:ALIGN_RIGHT:     
  ALIGN_RIGHT.

:ALIGN_JUSTIFY:   
  ALIGN_JUSTIFY.

:ALIGN_FLUSH:     
  ALIGN_FLUSH.

:ALIGN_TOP:       
  ALIGN_TOP.

:ALIGN_MIDDLE:    
  ALIGN_MIDDLE.

:ALIGN_BOTTOM:    
  ALIGN_BOTTOM.

:BOLD:            
  BOLD.

:ITALIC:          
  ITALIC.

:UNDERLINE:       
  UNDERLINE.

:SMALL_CAPS:      
  SMALL_CAPS.

:CON_ACTION:      
  CON_ACTION.

:MOD_ENVELOPE:    
  MOD_ENVELOPE.

:MOD_OUTLINE:     
  MOD_OUTLINE.

:MOD_LENGTH:      
  MOD_LENGTH.

:MOD_DASH:        
  MOD_DASH.

:MOD_LINEART:     
  MOD_LINEART.

:HOLDOUT_OFF:     
  HOLDOUT_OFF.

:HOLDOUT_ON:      
  HOLDOUT_ON.

:INDIRECT_ONLY_OFF:
  INDIRECT_ONLY_OFF.

:INDIRECT_ONLY_ON:
  INDIRECT_ONLY_ON.

:CON_CAMERASOLVER:
  CON_CAMERASOLVER.

:CON_FOLLOWTRACK: 
  CON_FOLLOWTRACK.

:CON_OBJECTSOLVER:
  CON_OBJECTSOLVER.

:CON_LOCLIKE:     
  CON_LOCLIKE.

:CON_ROTLIKE:     
  CON_ROTLIKE.

:CON_SIZELIKE:    
  CON_SIZELIKE.

:CON_TRANSLIKE:   
  CON_TRANSLIKE.

:CON_DISTLIMIT:   
  CON_DISTLIMIT.

:CON_LOCLIMIT:    
  CON_LOCLIMIT.

:CON_ROTLIMIT:    
  CON_ROTLIMIT.

:CON_SIZELIMIT:   
  CON_SIZELIMIT.

:CON_SAMEVOL:     
  CON_SAMEVOL.

:CON_TRANSFORM:   
  CON_TRANSFORM.

:CON_TRANSFORM_CACHE:
  CON_TRANSFORM_CACHE.

:CON_CLAMPTO:     
  CON_CLAMPTO.

:CON_KINEMATIC:   
  CON_KINEMATIC.

:CON_LOCKTRACK:   
  CON_LOCKTRACK.

:CON_SPLINEIK:    
  CON_SPLINEIK.

:CON_STRETCHTO:   
  CON_STRETCHTO.

:CON_TRACKTO:     
  CON_TRACKTO.

:CON_ARMATURE:    
  CON_ARMATURE.

:CON_CHILDOF:     
  CON_CHILDOF.

:CON_FLOOR:       
  CON_FLOOR.

:CON_FOLLOWPATH:  
  CON_FOLLOWPATH.

:CON_PIVOT:       
  CON_PIVOT.

:CON_SHRINKWRAP:  
  CON_SHRINKWRAP.

:MODIFIER_DATA:   
  MODIFIER_DATA.

:MOD_WAVE:        
  MOD_WAVE.

:MOD_BUILD:       
  MOD_BUILD.

:MOD_DECIM:       
  MOD_DECIM.

:MOD_MIRROR:      
  MOD_MIRROR.

:MOD_SOFT:        
  MOD_SOFT.

:MOD_SUBSURF:     
  MOD_SUBSURF.

:HOOK:            
  HOOK.

:MOD_PHYSICS:     
  MOD_PHYSICS.

:MOD_PARTICLES:   
  MOD_PARTICLES.

:MOD_BOOLEAN:     
  MOD_BOOLEAN.

:MOD_EDGESPLIT:   
  MOD_EDGESPLIT.

:MOD_ARRAY:       
  MOD_ARRAY.

:MOD_UVPROJECT:   
  MOD_UVPROJECT.

:MOD_DISPLACE:    
  MOD_DISPLACE.

:MOD_CURVE:       
  MOD_CURVE.

:MOD_LATTICE:     
  MOD_LATTICE.

:MOD_TINT:        
  MOD_TINT.

:MOD_ARMATURE:    
  MOD_ARMATURE.

:MOD_SHRINKWRAP:  
  MOD_SHRINKWRAP.

:MOD_CAST:        
  MOD_CAST.

:MOD_MESHDEFORM:  
  MOD_MESHDEFORM.

:MOD_BEVEL:       
  MOD_BEVEL.

:MOD_SMOOTH:      
  MOD_SMOOTH.

:MOD_SIMPLEDEFORM:
  MOD_SIMPLEDEFORM.

:MOD_MASK:        
  MOD_MASK.

:MOD_CLOTH:       
  MOD_CLOTH.

:MOD_EXPLODE:     
  MOD_EXPLODE.

:MOD_FLUIDSIM:    
  MOD_FLUIDSIM.

:MOD_MULTIRES:    
  MOD_MULTIRES.

:MOD_FLUID:       
  MOD_FLUID.

:MOD_SOLIDIFY:    
  MOD_SOLIDIFY.

:MOD_SCREW:       
  MOD_SCREW.

:MOD_VERTEX_WEIGHT:
  MOD_VERTEX_WEIGHT.

:MOD_DYNAMICPAINT:
  MOD_DYNAMICPAINT.

:MOD_REMESH:      
  MOD_REMESH.

:MOD_OCEAN:       
  MOD_OCEAN.

:MOD_WARP:        
  MOD_WARP.

:MOD_SKIN:        
  MOD_SKIN.

:MOD_TRIANGULATE: 
  MOD_TRIANGULATE.

:MOD_WIREFRAME:   
  MOD_WIREFRAME.

:MOD_DATA_TRANSFER:
  MOD_DATA_TRANSFER.

:MOD_NORMALEDIT:  
  MOD_NORMALEDIT.

:MOD_PARTICLE_INSTANCE:
  MOD_PARTICLE_INSTANCE.

:MOD_HUE_SATURATION:
  MOD_HUE_SATURATION.

:MOD_NOISE:       
  MOD_NOISE.

:MOD_OFFSET:      
  MOD_OFFSET.

:MOD_SIMPLIFY:    
  MOD_SIMPLIFY.

:MOD_THICKNESS:   
  MOD_THICKNESS.

:MOD_INSTANCE:    
  MOD_INSTANCE.

:MOD_TIME:        
  MOD_TIME.

:MOD_OPACITY:     
  MOD_OPACITY.

:REC:             
  REC.

:PLAY:            
  PLAY.

:FF:              
  FF.

:REW:             
  REW.

:PAUSE:           
  PAUSE.

:PREV_KEYFRAME:   
  PREV_KEYFRAME.

:NEXT_KEYFRAME:   
  NEXT_KEYFRAME.

:PLAY_SOUND:      
  PLAY_SOUND.

:PLAY_REVERSE:    
  PLAY_REVERSE.

:PREVIEW_RANGE:   
  PREVIEW_RANGE.

:ACTION_TWEAK:    
  ACTION_TWEAK.

:PMARKER_ACT:     
  PMARKER_ACT.

:PMARKER_SEL:     
  PMARKER_SEL.

:PMARKER:         
  PMARKER.

:MARKER_HLT:      
  MARKER_HLT.

:MARKER:          
  MARKER.

:KEYFRAME_HLT:    
  KEYFRAME_HLT.

:KEYFRAME:        
  KEYFRAME.

:KEYINGSET:       
  KEYINGSET.

:KEY_DEHLT:       
  KEY_DEHLT.

:KEY_HLT:         
  KEY_HLT.

:MUTE_IPO_OFF:    
  MUTE_IPO_OFF.

:MUTE_IPO_ON:     
  MUTE_IPO_ON.

:DRIVER:          
  DRIVER.

:SOLO_OFF:        
  SOLO_OFF.

:SOLO_ON:         
  SOLO_ON.

:FRAME_PREV:      
  FRAME_PREV.

:FRAME_NEXT:      
  FRAME_NEXT.

:NLA_PUSHDOWN:    
  NLA_PUSHDOWN.

:IPO_CONSTANT:    
  IPO_CONSTANT.

:IPO_LINEAR:      
  IPO_LINEAR.

:IPO_BEZIER:      
  IPO_BEZIER.

:IPO_SINE:        
  IPO_SINE.

:IPO_QUAD:        
  IPO_QUAD.

:IPO_CUBIC:       
  IPO_CUBIC.

:IPO_QUART:       
  IPO_QUART.

:IPO_QUINT:       
  IPO_QUINT.

:IPO_EXPO:        
  IPO_EXPO.

:IPO_CIRC:        
  IPO_CIRC.

:IPO_BOUNCE:      
  IPO_BOUNCE.

:IPO_ELASTIC:     
  IPO_ELASTIC.

:IPO_BACK:        
  IPO_BACK.

:IPO_EASE_IN:     
  IPO_EASE_IN.

:IPO_EASE_OUT:    
  IPO_EASE_OUT.

:IPO_EASE_IN_OUT: 
  IPO_EASE_IN_OUT.

:NORMALIZE_FCURVES:
  NORMALIZE_FCURVES.

:ORIENTATION_PARENT:
  ORIENTATION_PARENT.

:VERTEXSEL:       
  VERTEXSEL.

:EDGESEL:         
  EDGESEL.

:FACESEL:         
  FACESEL.

:CURSOR:          
  CURSOR.

:PIVOT_BOUNDBOX:  
  PIVOT_BOUNDBOX.

:PIVOT_CURSOR:    
  PIVOT_CURSOR.

:PIVOT_INDIVIDUAL:
  PIVOT_INDIVIDUAL.

:PIVOT_MEDIAN:    
  PIVOT_MEDIAN.

:PIVOT_ACTIVE:    
  PIVOT_ACTIVE.

:CENTER_ONLY:     
  CENTER_ONLY.

:ROOTCURVE:       
  ROOTCURVE.

:SMOOTHCURVE:     
  SMOOTHCURVE.

:SPHERECURVE:     
  SPHERECURVE.

:INVERSESQUARECURVE:
  INVERSESQUARECURVE.

:SHARPCURVE:      
  SHARPCURVE.

:LINCURVE:        
  LINCURVE.

:NOCURVE:         
  NOCURVE.

:RNDCURVE:        
  RNDCURVE.

:PROP_OFF:        
  PROP_OFF.

:PROP_ON:         
  PROP_ON.

:PROP_CON:        
  PROP_CON.

:PROP_PROJECTED:  
  PROP_PROJECTED.

:PARTICLE_POINT:  
  PARTICLE_POINT.

:PARTICLE_TIP:    
  PARTICLE_TIP.

:PARTICLE_PATH:   
  PARTICLE_PATH.

:SNAP_FACE_NEAREST:
  SNAP_FACE_NEAREST.

:SNAP_FACE_CENTER:
  SNAP_FACE_CENTER.

:SNAP_PERPENDICULAR:
  SNAP_PERPENDICULAR.

:SNAP_MIDPOINT:   
  SNAP_MIDPOINT.

:SNAP_OFF:        
  SNAP_OFF.

:SNAP_ON:         
  SNAP_ON.

:SNAP_NORMAL:     
  SNAP_NORMAL.

:SNAP_GRID:       
  SNAP_GRID.

:SNAP_VERTEX:     
  SNAP_VERTEX.

:SNAP_EDGE:       
  SNAP_EDGE.

:SNAP_FACE:       
  SNAP_FACE.

:SNAP_VOLUME:     
  SNAP_VOLUME.

:SNAP_INCREMENT:  
  SNAP_INCREMENT.

:STICKY_UVS_LOC:  
  STICKY_UVS_LOC.

:STICKY_UVS_DISABLE:
  STICKY_UVS_DISABLE.

:STICKY_UVS_VERT: 
  STICKY_UVS_VERT.

:CLIPUV_DEHLT:    
  CLIPUV_DEHLT.

:CLIPUV_HLT:      
  CLIPUV_HLT.

:SNAP_PEEL_OBJECT:
  SNAP_PEEL_OBJECT.

:GRID:            
  GRID.

:OBJECT_ORIGIN:   
  OBJECT_ORIGIN.

:ORIENTATION_GLOBAL:
  ORIENTATION_GLOBAL.

:ORIENTATION_GIMBAL:
  ORIENTATION_GIMBAL.

:ORIENTATION_LOCAL:
  ORIENTATION_LOCAL.

:ORIENTATION_NORMAL:
  ORIENTATION_NORMAL.

:ORIENTATION_VIEW:
  ORIENTATION_VIEW.

:COPYDOWN:        
  COPYDOWN.

:PASTEDOWN:       
  PASTEDOWN.

:PASTEFLIPUP:     
  PASTEFLIPUP.

:PASTEFLIPDOWN:   
  PASTEFLIPDOWN.

:VIS_SEL_11:      
  VIS_SEL_11.

:VIS_SEL_10:      
  VIS_SEL_10.

:VIS_SEL_01:      
  VIS_SEL_01.

:VIS_SEL_00:      
  VIS_SEL_00.

:AUTOMERGE_OFF:   
  AUTOMERGE_OFF.

:AUTOMERGE_ON:    
  AUTOMERGE_ON.

:UV_VERTEXSEL:    
  UV_VERTEXSEL.

:UV_EDGESEL:      
  UV_EDGESEL.

:UV_FACESEL:      
  UV_FACESEL.

:UV_ISLANDSEL:    
  UV_ISLANDSEL.

:UV_SYNC_SELECT:  
  UV_SYNC_SELECT.

:GP_CAPS_FLAT:    
  GP_CAPS_FLAT.

:GP_CAPS_ROUND:   
  GP_CAPS_ROUND.

:FIXED_SIZE:      
  FIXED_SIZE.

:TRANSFORM_ORIGINS:
  TRANSFORM_ORIGINS.

:GIZMO:           
  GIZMO.

:ORIENTATION_CURSOR:
  ORIENTATION_CURSOR.

:NORMALS_VERTEX:  
  NORMALS_VERTEX.

:NORMALS_FACE:    
  NORMALS_FACE.

:NORMALS_VERTEX_FACE:
  NORMALS_VERTEX_FACE.

:SHADING_BBOX:    
  SHADING_BBOX.

:SHADING_WIRE:    
  SHADING_WIRE.

:SHADING_SOLID:   
  SHADING_SOLID.

:SHADING_RENDERED:
  SHADING_RENDERED.

:SHADING_TEXTURE: 
  SHADING_TEXTURE.

:OVERLAY:         
  OVERLAY.

:XRAY:            
  XRAY.

:LOCKVIEW_OFF:    
  LOCKVIEW_OFF.

:LOCKVIEW_ON:     
  LOCKVIEW_ON.

:AXIS_SIDE:       
  AXIS_SIDE.

:AXIS_FRONT:      
  AXIS_FRONT.

:AXIS_TOP:        
  AXIS_TOP.

:LAYER_USED:      
  LAYER_USED.

:LAYER_ACTIVE:    
  LAYER_ACTIVE.

:OUTLINER_OB_CURVES:
  OUTLINER_OB_CURVES.

:OUTLINER_DATA_CURVES:
  OUTLINER_DATA_CURVES.

:CURVES_DATA:     
  CURVES_DATA.

:OUTLINER_OB_POINTCLOUD:
  OUTLINER_OB_POINTCLOUD.

:OUTLINER_DATA_POINTCLOUD:
  OUTLINER_DATA_POINTCLOUD.

:POINTCLOUD_DATA: 
  POINTCLOUD_DATA.

:OUTLINER_OB_VOLUME:
  OUTLINER_OB_VOLUME.

:OUTLINER_DATA_VOLUME:
  OUTLINER_DATA_VOLUME.

:VOLUME_DATA:     
  VOLUME_DATA.

:CURRENT_FILE:    
  CURRENT_FILE.

:HOME:            
  HOME.

:DOCUMENTS:       
  DOCUMENTS.

:TEMP:            
  TEMP.

:SORTALPHA:       
  SORTALPHA.

:SORTBYEXT:       
  SORTBYEXT.

:SORTTIME:        
  SORTTIME.

:SORTSIZE:        
  SORTSIZE.

:SHORTDISPLAY:    
  SHORTDISPLAY.

:LONGDISPLAY:     
  LONGDISPLAY.

:IMGDISPLAY:      
  IMGDISPLAY.

:BOOKMARKS:       
  BOOKMARKS.

:FONTPREVIEW:     
  FONTPREVIEW.

:FILTER:          
  FILTER.

:NEWFOLDER:       
  NEWFOLDER.

:FOLDER_REDIRECT: 
  FOLDER_REDIRECT.

:FILE_PARENT:     
  FILE_PARENT.

:FILE_REFRESH:    
  FILE_REFRESH.

:FILE_FOLDER:     
  FILE_FOLDER.

:FILE_BLANK:      
  FILE_BLANK.

:FILE_BLEND:      
  FILE_BLEND.

:FILE_IMAGE:      
  FILE_IMAGE.

:FILE_MOVIE:      
  FILE_MOVIE.

:FILE_SCRIPT:     
  FILE_SCRIPT.

:FILE_SOUND:      
  FILE_SOUND.

:FILE_FONT:       
  FILE_FONT.

:FILE_TEXT:       
  FILE_TEXT.

:SORT_DESC:       
  SORT_DESC.

:SORT_ASC:        
  SORT_ASC.

:LINK_BLEND:      
  LINK_BLEND.

:APPEND_BLEND:    
  APPEND_BLEND.

:IMPORT:          
  IMPORT.

:EXPORT:          
  EXPORT.

:LOOP_BACK:       
  LOOP_BACK.

:LOOP_FORWARDS:   
  LOOP_FORWARDS.

:BACK:            
  BACK.

:FORWARD:         
  FORWARD.

:FILE_ARCHIVE:    
  FILE_ARCHIVE.

:FILE_CACHE:      
  FILE_CACHE.

:FILE_VOLUME:     
  FILE_VOLUME.

:FILE_3D:         
  FILE_3D.

:FILE_HIDDEN:     
  FILE_HIDDEN.

:FILE_BACKUP:     
  FILE_BACKUP.

:DISK_DRIVE:      
  DISK_DRIVE.

:MATPLANE:        
  MATPLANE.

:MATSPHERE:       
  MATSPHERE.

:MATCUBE:         
  MATCUBE.

:MONKEY:          
  MONKEY.

:CURVES:          
  CURVES.

:ALIASED:         
  ALIASED.

:ANTIALIASED:     
  ANTIALIASED.

:MAT_SPHERE_SKY:  
  MAT_SPHERE_SKY.

:MATSHADERBALL:   
  MATSHADERBALL.

:MATCLOTH:        
  MATCLOTH.

:MATFLUID:        
  MATFLUID.

:WORDWRAP_OFF:    
  WORDWRAP_OFF.

:WORDWRAP_ON:     
  WORDWRAP_ON.

:SYNTAX_OFF:      
  SYNTAX_OFF.

:SYNTAX_ON:       
  SYNTAX_ON.

:LINENUMBERS_OFF: 
  LINENUMBERS_OFF.

:LINENUMBERS_ON:  
  LINENUMBERS_ON.

:SCRIPTPLUGINS:   
  SCRIPTPLUGINS.

:DISC:            
  DISC.

:DESKTOP:         
  DESKTOP.

:EXTERNAL_DRIVE:  
  EXTERNAL_DRIVE.

:NETWORK_DRIVE:   
  NETWORK_DRIVE.

:SEQ_SEQUENCER:   
  SEQ_SEQUENCER.

:SEQ_PREVIEW:     
  SEQ_PREVIEW.

:SEQ_LUMA_WAVEFORM:
  SEQ_LUMA_WAVEFORM.

:SEQ_CHROMA_SCOPE:
  SEQ_CHROMA_SCOPE.

:SEQ_HISTOGRAM:   
  SEQ_HISTOGRAM.

:SEQ_SPLITVIEW:   
  SEQ_SPLITVIEW.

:SEQ_STRIP_META:  
  SEQ_STRIP_META.

:SEQ_STRIP_DUPLICATE:
  SEQ_STRIP_DUPLICATE.

:IMAGE_RGB:       
  IMAGE_RGB.

:IMAGE_RGB_ALPHA: 
  IMAGE_RGB_ALPHA.

:IMAGE_ALPHA:     
  IMAGE_ALPHA.

:IMAGE_ZDEPTH:    
  IMAGE_ZDEPTH.

:HANDLE_AUTOCLAMPED:
  HANDLE_AUTOCLAMPED.

:HANDLE_AUTO:     
  HANDLE_AUTO.

:HANDLE_ALIGNED:  
  HANDLE_ALIGNED.

:HANDLE_VECTOR:   
  HANDLE_VECTOR.

:HANDLE_FREE:     
  HANDLE_FREE.

:VIEW_PERSPECTIVE:
  VIEW_PERSPECTIVE.

:VIEW_ORTHO:      
  VIEW_ORTHO.

:VIEW_CAMERA:     
  VIEW_CAMERA.

:VIEW_PAN:        
  VIEW_PAN.

:VIEW_ZOOM:       
  VIEW_ZOOM.

:BRUSH_BLOB:      
  BRUSH_BLOB.

:BRUSH_BLUR:      
  BRUSH_BLUR.

:BRUSH_CLAY:      
  BRUSH_CLAY.

:BRUSH_CLAY_STRIPS:
  BRUSH_CLAY_STRIPS.

:BRUSH_CLONE:     
  BRUSH_CLONE.

:BRUSH_CREASE:    
  BRUSH_CREASE.

:BRUSH_FILL:      
  BRUSH_FILL.

:BRUSH_FLATTEN:   
  BRUSH_FLATTEN.

:BRUSH_GRAB:      
  BRUSH_GRAB.

:BRUSH_INFLATE:   
  BRUSH_INFLATE.

:BRUSH_LAYER:     
  BRUSH_LAYER.

:BRUSH_MASK:      
  BRUSH_MASK.

:BRUSH_MIX:       
  BRUSH_MIX.

:BRUSH_NUDGE:     
  BRUSH_NUDGE.

:BRUSH_PAINT_SELECT:
  BRUSH_PAINT_SELECT.

:BRUSH_PINCH:     
  BRUSH_PINCH.

:BRUSH_SCRAPE:    
  BRUSH_SCRAPE.

:BRUSH_SCULPT_DRAW:
  BRUSH_SCULPT_DRAW.

:BRUSH_SMEAR:     
  BRUSH_SMEAR.

:BRUSH_SMOOTH:    
  BRUSH_SMOOTH.

:BRUSH_SNAKE_HOOK:
  BRUSH_SNAKE_HOOK.

:BRUSH_SOFTEN:    
  BRUSH_SOFTEN.

:BRUSH_TEXDRAW:   
  BRUSH_TEXDRAW.

:BRUSH_TEXFILL:   
  BRUSH_TEXFILL.

:BRUSH_TEXMASK:   
  BRUSH_TEXMASK.

:BRUSH_THUMB:     
  BRUSH_THUMB.

:BRUSH_ROTATE:    
  BRUSH_ROTATE.

:GPBRUSH_SMOOTH:  
  GPBRUSH_SMOOTH.

:GPBRUSH_THICKNESS:
  GPBRUSH_THICKNESS.

:GPBRUSH_STRENGTH:
  GPBRUSH_STRENGTH.

:GPBRUSH_GRAB:    
  GPBRUSH_GRAB.

:GPBRUSH_PUSH:    
  GPBRUSH_PUSH.

:GPBRUSH_TWIST:   
  GPBRUSH_TWIST.

:GPBRUSH_PINCH:   
  GPBRUSH_PINCH.

:GPBRUSH_RANDOMIZE:
  GPBRUSH_RANDOMIZE.

:GPBRUSH_CLONE:   
  GPBRUSH_CLONE.

:GPBRUSH_WEIGHT:  
  GPBRUSH_WEIGHT.

:GPBRUSH_PENCIL:  
  GPBRUSH_PENCIL.

:GPBRUSH_PEN:     
  GPBRUSH_PEN.

:GPBRUSH_INK:     
  GPBRUSH_INK.

:GPBRUSH_INKNOISE:
  GPBRUSH_INKNOISE.

:GPBRUSH_BLOCK:   
  GPBRUSH_BLOCK.

:GPBRUSH_MARKER:  
  GPBRUSH_MARKER.

:GPBRUSH_FILL:    
  GPBRUSH_FILL.

:GPBRUSH_AIRBRUSH:
  GPBRUSH_AIRBRUSH.

:GPBRUSH_CHISEL:  
  GPBRUSH_CHISEL.

:GPBRUSH_ERASE_SOFT:
  GPBRUSH_ERASE_SOFT.

:GPBRUSH_ERASE_HARD:
  GPBRUSH_ERASE_HARD.

:GPBRUSH_ERASE_STROKE:
  GPBRUSH_ERASE_STROKE.

:BRUSH_CURVES_ADD:
  BRUSH_CURVES_ADD.

:BRUSH_CURVES_COMB:
  BRUSH_CURVES_COMB.

:BRUSH_CURVES_CUT:
  BRUSH_CURVES_CUT.

:BRUSH_CURVES_DELETE:
  BRUSH_CURVES_DELETE.

:BRUSH_CURVES_DENSITY:
  BRUSH_CURVES_DENSITY.

:BRUSH_CURVES_GROW_SHRINK:
  BRUSH_CURVES_GROW_SHRINK.

:BRUSH_CURVES_PINCH:
  BRUSH_CURVES_PINCH.

:BRUSH_CURVES_PUFF:
  BRUSH_CURVES_PUFF.

:BRUSH_CURVES_SLIDE:
  BRUSH_CURVES_SLIDE.

:BRUSH_CURVES_SMOOTH:
  BRUSH_CURVES_SMOOTH.

:BRUSH_CURVES_SNAKE_HOOK:
  BRUSH_CURVES_SNAKE_HOOK.

:KEYTYPE_KEYFRAME_VEC:
  KEYTYPE_KEYFRAME_VEC.

:KEYTYPE_BREAKDOWN_VEC:
  KEYTYPE_BREAKDOWN_VEC.

:KEYTYPE_EXTREME_VEC:
  KEYTYPE_EXTREME_VEC.

:KEYTYPE_JITTER_VEC:
  KEYTYPE_JITTER_VEC.

:KEYTYPE_MOVING_HOLD_VEC:
  KEYTYPE_MOVING_HOLD_VEC.

:HANDLETYPE_FREE_VEC:
  HANDLETYPE_FREE_VEC.

:HANDLETYPE_ALIGNED_VEC:
  HANDLETYPE_ALIGNED_VEC.

:HANDLETYPE_VECTOR_VEC:
  HANDLETYPE_VECTOR_VEC.

:HANDLETYPE_AUTO_VEC:
  HANDLETYPE_AUTO_VEC.

:HANDLETYPE_AUTO_CLAMP_VEC:
  HANDLETYPE_AUTO_CLAMP_VEC.

:COLORSET_01_VEC: 
  COLORSET_01_VEC.

:COLORSET_02_VEC: 
  COLORSET_02_VEC.

:COLORSET_03_VEC: 
  COLORSET_03_VEC.

:COLORSET_04_VEC: 
  COLORSET_04_VEC.

:COLORSET_05_VEC: 
  COLORSET_05_VEC.

:COLORSET_06_VEC: 
  COLORSET_06_VEC.

:COLORSET_07_VEC: 
  COLORSET_07_VEC.

:COLORSET_08_VEC: 
  COLORSET_08_VEC.

:COLORSET_09_VEC: 
  COLORSET_09_VEC.

:COLORSET_10_VEC: 
  COLORSET_10_VEC.

:COLORSET_11_VEC: 
  COLORSET_11_VEC.

:COLORSET_12_VEC: 
  COLORSET_12_VEC.

:COLORSET_13_VEC: 
  COLORSET_13_VEC.

:COLORSET_14_VEC: 
  COLORSET_14_VEC.

:COLORSET_15_VEC: 
  COLORSET_15_VEC.

:COLORSET_16_VEC: 
  COLORSET_16_VEC.

:COLORSET_17_VEC: 
  COLORSET_17_VEC.

:COLORSET_18_VEC: 
  COLORSET_18_VEC.

:COLORSET_19_VEC: 
  COLORSET_19_VEC.

:COLORSET_20_VEC: 
  COLORSET_20_VEC.

:COLLECTION_COLOR_01:
  COLLECTION_COLOR_01.

:COLLECTION_COLOR_02:
  COLLECTION_COLOR_02.

:COLLECTION_COLOR_03:
  COLLECTION_COLOR_03.

:COLLECTION_COLOR_04:
  COLLECTION_COLOR_04.

:COLLECTION_COLOR_05:
  COLLECTION_COLOR_05.

:COLLECTION_COLOR_06:
  COLLECTION_COLOR_06.

:COLLECTION_COLOR_07:
  COLLECTION_COLOR_07.

:COLLECTION_COLOR_08:
  COLLECTION_COLOR_08.

:SEQUENCE_COLOR_01:
  SEQUENCE_COLOR_01.

:SEQUENCE_COLOR_02:
  SEQUENCE_COLOR_02.

:SEQUENCE_COLOR_03:
  SEQUENCE_COLOR_03.

:SEQUENCE_COLOR_04:
  SEQUENCE_COLOR_04.

:SEQUENCE_COLOR_05:
  SEQUENCE_COLOR_05.

:SEQUENCE_COLOR_06:
  SEQUENCE_COLOR_06.

:SEQUENCE_COLOR_07:
  SEQUENCE_COLOR_07.

:SEQUENCE_COLOR_08:
  SEQUENCE_COLOR_08.

:SEQUENCE_COLOR_09:
  SEQUENCE_COLOR_09.

:LIBRARY_DATA_INDIRECT:
  LIBRARY_DATA_INDIRECT.

:LIBRARY_DATA_OVERRIDE_NONEDITABLE:
  LIBRARY_DATA_OVERRIDE_NONEDITABLE.

:EVENT_A:         
  EVENT_A.

:EVENT_B:         
  EVENT_B.

:EVENT_C:         
  EVENT_C.

:EVENT_D:         
  EVENT_D.

:EVENT_E:         
  EVENT_E.

:EVENT_F:         
  EVENT_F.

:EVENT_G:         
  EVENT_G.

:EVENT_H:         
  EVENT_H.

:EVENT_I:         
  EVENT_I.

:EVENT_J:         
  EVENT_J.

:EVENT_K:         
  EVENT_K.

:EVENT_L:         
  EVENT_L.

:EVENT_M:         
  EVENT_M.

:EVENT_N:         
  EVENT_N.

:EVENT_O:         
  EVENT_O.

:EVENT_P:         
  EVENT_P.

:EVENT_Q:         
  EVENT_Q.

:EVENT_R:         
  EVENT_R.

:EVENT_S:         
  EVENT_S.

:EVENT_T:         
  EVENT_T.

:EVENT_U:         
  EVENT_U.

:EVENT_V:         
  EVENT_V.

:EVENT_W:         
  EVENT_W.

:EVENT_X:         
  EVENT_X.

:EVENT_Y:         
  EVENT_Y.

:EVENT_Z:         
  EVENT_Z.

:EVENT_SHIFT:     
  EVENT_SHIFT.

:EVENT_CTRL:      
  EVENT_CTRL.

:EVENT_ALT:       
  EVENT_ALT.

:EVENT_OS:        
  EVENT_OS.

:EVENT_F1:        
  EVENT_F1.

:EVENT_F2:        
  EVENT_F2.

:EVENT_F3:        
  EVENT_F3.

:EVENT_F4:        
  EVENT_F4.

:EVENT_F5:        
  EVENT_F5.

:EVENT_F6:        
  EVENT_F6.

:EVENT_F7:        
  EVENT_F7.

:EVENT_F8:        
  EVENT_F8.

:EVENT_F9:        
  EVENT_F9.

:EVENT_F10:       
  EVENT_F10.

:EVENT_F11:       
  EVENT_F11.

:EVENT_F12:       
  EVENT_F12.

:EVENT_ESC:       
  EVENT_ESC.

:EVENT_TAB:       
  EVENT_TAB.

:EVENT_PAGEUP:    
  EVENT_PAGEUP.

:EVENT_PAGEDOWN:  
  EVENT_PAGEDOWN.

:EVENT_RETURN:    
  EVENT_RETURN.

:EVENT_SPACEKEY:  
  EVENT_SPACEKEY.

.. _rna-enum-icon-items:

"""

import typing
