"""


Node Socket Type Items
^^^^^^^^^^^^^^^^^^^^^^

:CUSTOM:          
  Custom.

:VALUE:           
  Value.

:INT:             
  Integer.

:BOOLEAN:         
  Boolean.

:VECTOR:          
  Vector.

:ROTATION:        
  Rotation.

:STRING:          
  String.

:RGBA:            
  RGBA.

:SHADER:          
  Shader.

:OBJECT:          
  Object.

:IMAGE:           
  Image.

:GEOMETRY:        
  Geometry.

:COLLECTION:      
  Collection.

:TEXTURE:         
  Texture.

:MATERIAL:        
  Material.

.. _rna-enum-node-socket-type-items:

"""

import typing
