"""


Object Shaderfx Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:FX_BLUR:         
  Blur.

  Apply Gaussian Blur to object.

:FX_COLORIZE:     
  Colorize.

  Apply different tint effects.

:FX_FLIP:         
  Flip.

  Flip image.

:FX_GLOW:         
  Glow.

  Create a glow effect.

:FX_PIXEL:        
  Pixelate.

  Pixelate image.

:FX_RIM:          
  Rim.

  Add a rim to the image.

:FX_SHADOW:       
  Shadow.

  Create a shadow effect.

:FX_SWIRL:        
  Swirl.

  Create a rotation distortion.

:FX_WAVE:         
  Wave Distortion.

  Apply sinusoidal deformation.

.. _rna-enum-object-shaderfx-type-items:

"""

import typing
