"""


Dt Mix Mode Items
^^^^^^^^^^^^^^^^^

:REPLACE:         
  Replace.

  Overwrite all elements' data.

:ABOVE_THRESHOLD: 
  Above Threshold.

  Only replace destination elements where data is above given threshold (exact behavior depends on data type).

:BELOW_THRESHOLD: 
  Below Threshold.

  Only replace destination elements where data is below given threshold (exact behavior depends on data type).

:MIX:             
  Mix.

  Mix source value into destination one, using given threshold as factor.

:ADD:             
  Add.

  Add source value to destination one, using given threshold as factor.

:SUB:             
  Subtract.

  Subtract source value to destination one, using given threshold as factor.

:MUL:             
  Multiply.

  Multiply source value to destination one, using given threshold as factor.

.. _rna-enum-dt-mix-mode-items:

"""

import typing
