"""


Brush Sculpt Tool Items
^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:DRAW_SHARP:      
  Draw Sharp.

:CLAY:            
  Clay.

:CLAY_STRIPS:     
  Clay Strips.

:CLAY_THUMB:      
  Clay Thumb.

:LAYER:           
  Layer.

:INFLATE:         
  Inflate.

:BLOB:            
  Blob.

:CREASE:          
  Crease.

.. _rna-enum-brush-sculpt-tool-items:

======================================================================

:SMOOTH:          
  Smooth.

:FLATTEN:         
  Flatten.

:FILL:            
  Fill.

:SCRAPE:          
  Scrape.

:MULTIPLANE_SCRAPE:
  Multi-plane Scrape.

:PINCH:           
  Pinch.

======================================================================

:GRAB:            
  Grab.

:ELASTIC_DEFORM:  
  Elastic Deform.

:SNAKE_HOOK:      
  Snake Hook.

:THUMB:           
  Thumb.

:POSE:            
  Pose.

:NUDGE:           
  Nudge.

:ROTATE:          
  Rotate.

:TOPOLOGY:        
  Slide Relax.

:BOUNDARY:        
  Boundary.

======================================================================

:CLOTH:           
  Cloth.

:SIMPLIFY:        
  Simplify.

:MASK:            
  Mask.

:DRAW_FACE_SETS:  
  Draw Face Sets.

:DISPLACEMENT_ERASER:
  Multires Displacement Eraser.

:DISPLACEMENT_SMEAR:
  Multires Displacement Smear.

:PAINT:           
  Paint.

:SMEAR:           
  Smear.

"""

import typing
