"""


Operator Context Items
^^^^^^^^^^^^^^^^^^^^^^

:INVOKE_DEFAULT:  
  Invoke Default.

:INVOKE_REGION_WIN:
  Invoke Region Window.

:INVOKE_REGION_CHANNELS:
  Invoke Region Channels.

:INVOKE_REGION_PREVIEW:
  Invoke Region Preview.

:INVOKE_AREA:     
  Invoke Area.

:INVOKE_SCREEN:   
  Invoke Screen.

:EXEC_DEFAULT:    
  Exec Default.

:EXEC_REGION_WIN: 
  Exec Region Window.

:EXEC_REGION_CHANNELS:
  Exec Region Channels.

:EXEC_REGION_PREVIEW:
  Exec Region Preview.

:EXEC_AREA:       
  Exec Area.

:EXEC_SCREEN:     
  Exec Screen.

.. _rna-enum-operator-context-items:

"""

import typing
