"""


Attribute Domain Only Mesh Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Attribute on point.

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

:CORNER:          
  Face Corner.

  Attribute on mesh face corner.

.. _rna-enum-attribute-domain-only-mesh-items:

"""

import typing
