"""


Transform Pivot Items Full
^^^^^^^^^^^^^^^^^^^^^^^^^^

:BOUNDING_BOX_CENTER:
  Bounding Box Center.

  Pivot around bounding box center of selected object(s).

:CURSOR:          
  3D Cursor.

  Pivot around the 3D cursor.

:INDIVIDUAL_ORIGINS:
  Individual Origins.

  Pivot around each object's own origin.

:MEDIAN_POINT:    
  Median Point.

  Pivot around the median point of selected objects.

:ACTIVE_ELEMENT:  
  Active Element.

  Pivot around active object.

.. _rna-enum-transform-pivot-items-full:

"""

import typing
