"""


Image Color Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:BW:              
  BW.

  Images get saved in 8-bit grayscale (only PNG, JPEG, TGA, TIF).

:RGB:             
  RGB.

  Images are saved with RGB (color) data.

:RGBA:            
  RGBA.

  Images are saved with RGB and Alpha data (if supported).

.. _rna-enum-image-color-mode-items:

"""

import typing
