"""


Fmodifier Type Items
^^^^^^^^^^^^^^^^^^^^

:nullptr:         
  Invalid.

:GENERATOR:       
  Generator.

  Generate a curve using a factorized or expanded polynomial.

:FNGENERATOR:     
  Built-In Function.

  Generate a curve using standard math functions such as sin and cos.

:ENVELOPE:        
  Envelope.

  Reshape F-Curve values, e.g. change amplitude of movements.

:CYCLES:          
  Cycles.

  Cyclic extend/repeat keyframe sequence.

:NOISE:           
  Noise.

  Add pseudo-random noise on top of F-Curves.

:LIMITS:          
  Limits.

  Restrict maximum and minimum values of F-Curve.

:STEPPED:         
  Stepped Interpolation.

  Snap values to nearest grid step, e.g. for a stop-motion look.

.. _rna-enum-fmodifier-type-items:

"""

import typing
