"""


Curves Types
^^^^^^^^^^^^

:CATMULL_ROM:     
  Catmull Rom.

:POLY:            
  Poly.

:BEZIER:          
  Bezier.

:NURBS:           
  NURBS.

.. _rna-enum-curves-types:

"""

import typing
