"""


Nla Mode Extend Items
^^^^^^^^^^^^^^^^^^^^^

:NOTHING:         
  Nothing.

  Strip has no influence past its extents.

:HOLD:            
  Hold.

  Hold the first frame if no previous strips in track, and always hold last frame.

:HOLD_FORWARD:    
  Hold Forward.

  Only hold last frame.

.. _rna-enum-nla-mode-extend-items:

"""

import typing
