"""


Beztriple Interpolation Easing Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:AUTO:            
  Automatic Easing.

  Easing type is chosen automatically based on what the type of interpolation used (e.g. Ease In for transitional types, and Ease Out for dynamic effects).

:EASE_IN:         
  Ease In.

  Only on the end closest to the next keyframe.

:EASE_OUT:        
  Ease Out.

  Only on the end closest to the first keyframe.

:EASE_IN_OUT:     
  Ease In and Out.

  Segment between both keyframes.

.. _rna-enum-beztriple-interpolation-easing-items:

"""

import typing
