"""


Sequence Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BRIGHT_CONTRAST: 
  Brightness/Contrast.

:COLOR_BALANCE:   
  Color Balance.

:CURVES:          
  Curves.

:HUE_CORRECT:     
  Hue Correct.

:MASK:            
  Mask.

:TONEMAP:         
  Tone Map.

:WHITE_BALANCE:   
  White Balance.

.. _rna-enum-sequence-modifier-type-items:

"""

import typing
