"""


Beztriple Keyframe Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:KEYFRAME:        
  Keyframe.

  Normal keyframe, e.g. for key poses.

:BREAKDOWN:       
  Breakdown.

  A breakdown pose, e.g. for transitions between key poses.

:MOVING_HOLD:     
  Moving Hold.

  A keyframe that is part of a moving hold.

:EXTREME:         
  Extreme.

  An "extreme" pose, or some other purpose as needed.

:JITTER:          
  Jitter.

  A filler or baked keyframe for keying on ones, or some other purpose as needed.

.. _rna-enum-beztriple-keyframe-type-items:

"""

import typing
