"""


Bake Pass Filter Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:EMIT:            
  Emit.

:DIRECT:          
  Direct.

:INDIRECT:        
  Indirect.

:COLOR:           
  Color.

:DIFFUSE:         
  Diffuse.

:GLOSSY:          
  Glossy.

:TRANSMISSION:    
  Transmission.

.. _rna-enum-bake-pass-filter-type-items:

"""

import typing
