"""


Bake Target Items
^^^^^^^^^^^^^^^^^

:IMAGE_TEXTURES:  
  Image Textures.

  Bake to image data-blocks associated with active image texture nodes in materials.

:VERTEX_COLORS:   
  Active Color Attribute.

  Bake to the active color attribute on meshes.

.. _rna-enum-bake-target-items:

"""

import typing
