"""


Object Empty Drawtype Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:PLAIN_AXES:      
  Plain Axes.

:ARROWS:          
  Arrows.

:SINGLE_ARROW:    
  Single Arrow.

:CIRCLE:          
  Circle.

:CUBE:            
  Cube.

:SPHERE:          
  Sphere.

:CONE:            
  Cone.

:IMAGE:           
  Image.

.. _rna-enum-object-empty-drawtype-items:

"""

import typing
