"""


Object Gpencil Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^

:EMPTY:           
  Blank.

  Create an empty grease pencil object.

:STROKE:          
  Stroke.

  Create a simple stroke with basic colors.

:MONKEY:          
  Monkey.

  Construct a Suzanne grease pencil object.

.. _rna-enum-object-gpencil-type-items:

======================================================================

:LRT_SCENE:       
  Scene Line Art.

  Quickly set up line art for the entire scene.

:LRT_COLLECTION:  
  Collection Line Art.

  Quickly set up line art for the active collection.

:LRT_OBJECT:      
  Object Line Art.

  Quickly set up line art for the active object.

"""

import typing
