"""


Script Operators
****************

:func:`execute_preset`

:func:`python_file_run`

:func:`reload`

"""

import typing

def execute_preset(filepath: str = '', menu_idname: str = '') -> None:

  """

  Load a preset

  """

  ...

def python_file_run(filepath: str = '') -> None:

  """

  Run Python file

  """

  ...

def reload() -> None:

  """

  Reload scripts

  """

  ...
