"""


Color Space Convert Default Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

  Do not perform any color transform on load, treat colors as in scene linear space already.

.. _rna-enum-color-space-convert-default-items:

"""

import typing
