"""


Shading Type Items
^^^^^^^^^^^^^^^^^^

:WIREFRAME:       
  Wireframe.

  Display the object as wire edges.

:SOLID:           
  Solid.

  Display in solid mode.

:MATERIAL:        
  Material Preview.

  Display in Material Preview mode.

:RENDERED:        
  Rendered.

  Display render preview.

.. _rna-enum-shading-type-items:

"""

import typing
