"""


Attribute Domain With Auto Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:AUTO:            
  Auto.

:POINT:           
  Point.

  Attribute on point.

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

:CORNER:          
  Face Corner.

  Attribute on mesh face corner.

:CURVE:           
  Spline.

  Attribute on spline.

:INSTANCE:        
  Instance.

  Attribute on instance.

.. _rna-enum-attribute-domain-with-auto-items:

"""

import typing
