"""


Curve Normal Modes
^^^^^^^^^^^^^^^^^^

:MINIMUM_TWIST:   
  Minimum Twist.

  Calculate normals with the smallest twist around the curve tangent across the whole curve.

:Z_UP:            
  Z Up.

  Calculate normals perpendicular to the Z axis and the curve tangent. If a series of points is vertical, the X axis is used.

.. _rna-enum-curve-normal-modes:

"""

import typing
