"""


Operator Property Tags
^^^^^^^^^^^^^^^^^^^^^^

:ADVANCED:        
  Advanced.

  The property is advanced so UI is suggested to hide it.

.. _rna-enum-operator-property-tags:

"""

import typing
