"""


Surface Operators
*****************

:func:`primitive_nurbs_surface_circle_add`

:func:`primitive_nurbs_surface_curve_add`

:func:`primitive_nurbs_surface_cylinder_add`

:func:`primitive_nurbs_surface_sphere_add`

:func:`primitive_nurbs_surface_surface_add`

:func:`primitive_nurbs_surface_torus_add`

"""

import typing

import mathutils

def primitive_nurbs_surface_circle_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs surface Circle

  """

  ...

def primitive_nurbs_surface_curve_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs surface Curve

  """

  ...

def primitive_nurbs_surface_cylinder_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs surface Cylinder

  """

  ...

def primitive_nurbs_surface_sphere_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs surface Sphere

  """

  ...

def primitive_nurbs_surface_surface_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs surface Patch

  """

  ...

def primitive_nurbs_surface_torus_add(radius: float = 1.0, enter_editmode: bool = False, align: str = 'WORLD', location: mathutils.Vector = (0.0, 0.0, 0.0), rotation: mathutils.Euler = (0.0, 0.0, 0.0), scale: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Construct a Nurbs surface Torus

  """

  ...
