"""


Particle Edit Disconnected Hair Brush Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:COMB:            
  Comb.

  Comb hairs.

:SMOOTH:          
  Smooth.

  Smooth hairs.

:LENGTH:          
  Length.

  Make hairs longer or shorter.

:CUT:             
  Cut.

  Cut hairs.

:WEIGHT:          
  Weight.

  Weight hair particles.

.. _rna-enum-particle-edit-disconnected-hair-brush-items:

"""

import typing
