"""


Event Value Items
^^^^^^^^^^^^^^^^^

:ANY:             
  Any.

:PRESS:           
  Press.

:RELEASE:         
  Release.

:CLICK:           
  Click.

:DOUBLE_CLICK:    
  Double Click.

:CLICK_DRAG:      
  Click Drag.

:NOTHING:         
  Nothing.

.. _rna-enum-event-value-items:

"""

import typing
